/* lsmbox.h
 *
 * Copyright (C) 2003 David Weinehall
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software Foundation,
 *  Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
#ifndef _LSMBOX_H_
#define _LSMBOX_H_

#include <locale.h>

#if ENABLE_NLS
#include <libintl.h>
#define _(__str)		gettext(__str)
#else
#undef bindtextdomain
#define bindtextdomain(__domain, __directory)
#undef textdomain
#define textdomain(__domain)
#define _(__str)		__str
#endif /* ENABLE_NLS */

#define __stringify_1(x)	#x
#define __stringify(x)		__stringify_1(x)

#define SPOOLFILE_PATH		"/var/mail"	/* username follows */
#define MAILBOX_FOLDER_PATH	"Mail"		/* $HOME preceeds */

#define SET_STR			"set"
#define UNSET_STR		"unset"
#define MARK_OLD_STR		"mark_old"
#define SPOOLFILE_STR		"spoolfile"
#define MAILBOX_FOLDER_STR	"folder"
#define MAILBOX_STR		"mailboxes"
#define MH_SEQ_UNSEEN_STR	"mh_seq_unseen"

#define UNSEEN_STR		"unseen"

#define FROM_STR		"From "
#define STATUS_STR		"Status: "
#define CONTENT_LENGTH_STR	"Content-Length: "

#define BUF_SIZE		65536

#define MAILCHECK_DEFAULT	10
#define MAILCHECK_MINIMUM	3

#define SKIP_EQ			(1 << 0)
#define SKIP_QU			(1 << 1)

#if !defined __GNUC__ || __GNUC__ == 2 && __GNUC_MINOR__ < 96
#define __builtin_expect(__x, __expected_value) (__x)
#endif

#ifndef likely
#define likely(__x)       __builtin_expect((__x) != 0, 1)
#endif /* likely */

#ifndef unlikely
#define unlikely(__x)     __builtin_expect((__x) != 0, 0)
#endif /* unlikely */

#ifdef USE_CURSES
#define OPTSTR		"ci:nosSt"
#else
#define OPTSTR		"nosSt"
#endif /* USE_CURSES */

	struct option const options[] = {
#ifdef USE_CURSES
		{ "continuous", no_argument, 0, 'c' },
		{ "check-interval", required_argument, 0, 'i' },
#endif /* USE_CURSES */
		{ "new-only", no_argument, 0, 'n' },
		{ "no-old", no_argument, 0, 'o' },
		{ "no-summary", no_argument, 0, 's' },
		{ "short-names", no_argument, 0, 'S' },
		{ "no-total", no_argument, 0, 't' },
		{ "help", no_argument, 0, 'h' },
		{ "version", no_argument, 0, 'V' },
		{ 0, 0, 0, 0 }
	};

typedef enum {
	MBOX,
	MAILDIR,
	MHDIR
} mbox_type_t;

typedef enum {
	E_OK,
	E_SYNTAX,
	E_UNKNOWN
} lsmbox_error_t;

#endif /* _LSMBOX_H_ */
